bug-make
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Re: Bug#72802: make fails to correctly echo commands


From: Paul D. Smith
Subject: Re: Bug#72802: make fails to correctly echo commands
Date: Wed, 2 May 2001 01:42:05 -0400

%% Manoj Srivastava <address@hidden> writes:
         
  ms> make 3.79.1 is not correctly echoing commands when they occur in
  ms> canned command sequences.

This problem can be fixed with the following patch.  This will be
included in the next release of GNU make.  Thanks for your bug report.


--- make-3.79.1/job.c   Fri Jun 23 11:54:56 2000
+++ make/job.c  Wed May  2 01:17:08 2001
@@ -895,8 +895,14 @@
       ++p;
     }
 
-  /* Update the file's command flags with any new ones we found.  */
-  child->file->cmds->lines_flags[child->command_line - 1] |= flags;
+  /* Update the file's command flags with any new ones we found.  We only
+     keep the COMMANDS_RECURSE setting.  Even this isn't 100% correct; we are
+     now marking more commands recursive than should be in the case of
+     multiline define/endef scripts where only one line is marked "+".  In
+     order to really fix this, we'll have to keep a lines_flags for every
+     actual line, after expansion.  */
+  child->file->cmds->lines_flags[child->command_line - 1]
+    |= flags & COMMANDS_RECURSE;
 
   /* Figure out an argument list from this command line.  */
 
-- 
-------------------------------------------------------------------------------
 Paul D. Smith <address@hidden>          Find some GNU make tips at:
 http://www.gnu.org                      http://www.paulandlesley.org/gmake/
 "Please remain calm...I may be mad, but I am a professional." --Mad Scientist



reply via email to

[Prev in Thread] Current Thread [Next in Thread]